@@ -12,10 +12,10 @@ from coursebox.core.info_paths import core_conf
 # import pybtex.database.input.bibtex
 # import pybtex.plugin
 # import io
-from line_profiler_pycharm import profile
+# from line_profiler_pycharm import profile
 import time
 
-@profile
+# @profile
 def xlsx_to_dicts(xlsx_file,sheet=None, as_dict_list=False):
     # print("Loading...", xlsx_file, sheet, as_dict_list)
     t0 = time.time()
@@ -245,7 +245,7 @@ def get_forum(paths):
         d2.append({k: v[i] for k, v in dd.items()})
     return d2
 
-@profile
+# @profile
 def class_information():
     course_number = core_conf['course_number']
     piazza = 'https://piazza.com/dtu.dk/%s%s/%s' % (semester().lower(), year(), course_number)
